<?php

namespace Albaraha\Patient\Providers;

use Illuminate\Support\ServiceProvider;

class PatientServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'patient');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'patient');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('albaraha.patient', function ($app) {
            return $this->app->make('Albaraha\Patient\Patient');
        });

                // Bind Patient to repository
        $this->app->bind(
            'Albaraha\Patient\Interfaces\PatientRepositoryInterface',
            \Albaraha\Patient\Repositories\Eloquent\PatientRepository::class
        );

        $this->app->register(\Albaraha\Patient\Providers\AuthServiceProvider::class);
                $this->app->register(\Albaraha\Patient\Providers\EventServiceProvider::class);
        
        $this->app->register(\Albaraha\Patient\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['albaraha.patient'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('albaraha/patient.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/patient')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/patient')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
